summer API doc — summer 0.7.5 documentation

# summer API doc

Contents:

- Core modules
- ORM – object relational mapping
- LDAP – lightweight directory access)
- AOP modules
- Producer–Consumer
- Miscellaneous modules

Summer is light weight Python framework to support some common tasks in variety of applications. It tries to assist you with:

- Managing objects that implement your business logic.

- Using SQL transactions by simply decorating methods as @transactional.

- Using LDAP sessions by simply decorating methods as @ldapaop.

- Using gettext for localization.

With summer you can:

- Create and configure your stateless objects and deploy them into a simple container to be ready for any later use.

- Declaratively create transaction proxies or programmatically manage transactions.

- Declaratively create ldap proxies or programmatically manage ldap sessions.

- Get gettext l10n configured fast and ready to use.

Reasons to name it summer:

- I wrote it in winter.

- You may know Java based spring framework, which was my inspiration.

Summer’s top level module simply imports public API classes and methods into summer namespace.